/*
 * Gestion du fichier agsp-conf.properties. qui permet de parametrer l'app
 * 
 */
package com.agriscope.rcp.client.exemple;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;
import java.util.logging.Level;
import org.apache.log4j.Logger;

/**
 *
 * @author guillaume
 */
public class ConnectionOptions
{

    transient protected Logger log = Logger.getLogger(ConnectionOptions.class);
    final private String SERVER_URL = "agriscope.server";
    final private String LOGIN = "user";
    final private String PASSWD = "passwd";
    private String fileName = "agsp-conf.properties";
    private String serverUrl;
    private String login;
    private String passwd;
    private File propsFile;
    Properties props = new Properties();

    public ConnectionOptions()
    {
        boolean propsFileExist = initFiles();
        if (!propsFileExist)
        {
            setDefaultProperties();
            saveProperiesInFile();
        }
        this.loadOptionsFromFile();

    }

    private void setDefaultProperties()
    {
        props.setProperty(SERVER_URL, "http://dev.agriscope.fr:8084/agriscope-web/rcp");
        props.setProperty(LOGIN, "login");
        props.setProperty(PASSWD, "5dddd");
    }

    private void saveProperiesInFile()
    {
        try
        {
            log.info("save properties in file '" + propsFile.getCanonicalPath() + "'");
        } catch (IOException ex)
        {
            java.util.logging.Logger.getLogger(ConnectionOptions.class.getName()).log(Level.SEVERE, null, ex);
        }

        FileOutputStream os;
        try
        {
            os = new FileOutputStream(propsFile);
        } catch (FileNotFoundException ex)
        {
            log.warn("impossible d'enregister le fichier " + fileName + "\n===> Message d'erreur : " + ex.getLocalizedMessage());
            return;
        }
        try
        {
            props.store(os, "comments added automatically");
        } catch (IOException ex)
        {
            log.warn("impossible d'enregister les proprietes dans le fichier");
            return;
        }



    }

    private boolean initFiles()
    {
        boolean isPropsFileExist = true;

        propsFile = new File(fileName);
        if (!propsFile.exists())
        {
            try
            {
                propsFile.createNewFile();
                this.setDefaultProperties();
                this.saveProperiesInFile();
            } catch (IOException ex)
            {
                isPropsFileExist = false;
                log.error(ex);
            }

        }
        return isPropsFileExist;
    }

    private void loadOptionsFromFile()
    {
        try
        {
            props.load(new FileInputStream(propsFile));
        } catch (IOException ex)
        {
            log.error(ex);
        }
    }

    public String getFileName()
    {
        String returnv = "";
        try
        {
            returnv = propsFile.getCanonicalPath(); 
        }
        catch (Exception e)
        {
            log.error (e);
        }
                
        return  returnv;
    }

    public String getServerUrl()
    {
        return props.getProperty(SERVER_URL);
    }

    public void setServerUrl(String serverUrl)
    {
        props.setProperty(SERVER_URL, serverUrl);
        this.saveProperiesInFile();
    }

    public String getLogin()
    {
        return props.getProperty(LOGIN);
    }

    public void setLogin(String login)
    {

        props.setProperty(LOGIN, login);
        this.saveProperiesInFile();
    }

    public String getPasswd()
    {
        return props.getProperty(PASSWD);
    }

    public void setPasswd(String passwd)
    {

        props.setProperty(PASSWD, passwd);
        this.saveProperiesInFile();
    }
}
