/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package com.agriscope.rcp.client.exemple;

import com.agriscope.exported.AgriscopeWS;
import com.agriscope.exported.AgspException;
import com.agriscope.exported.AgspSatellite;
import com.agriscope.exported.AgspSensor;
import com.agriscope.exported.LoginContext;
import java.text.DateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.logging.Level;
import org.apache.log4j.Logger;
import org.jfree.data.time.RegularTimePeriod;
import org.jfree.data.time.TimePeriod;
import org.jfree.data.time.TimeSeries;
import org.springframework.context.support.ClassPathXmlApplicationContext;
import org.springframework.remoting.httpinvoker.HttpInvokerProxyFactoryBean;

/**
 *
 * @author guillaume
 */
public class GetData
{

    /* logger */
    transient protected Logger log = Logger.getLogger(GetData.class);
    /* spring context */
    private ClassPathXmlApplicationContext ac = null;    // Stored login context
    /* agriscope WS context, contient l'id de la session ouverte */
    LoginContext loginContext = null;    // Stored connection
    /* WS agriscope */
    AgriscopeWS agsp;
    /* Options de lapp */
    private ConnectionOptions options;

    public GetData()
    {
    }

    /*
     * ********************************************************************
     * 
     *  1 Procedure de connection au serveur
     * 
     * *********************************************************************
     */
    LoginContext connect()
    {
        /*
         * ********************************************************************
         * 
         *  Lecture du agsp-conf.properties
         * 
         * *********************************************************************
         */
        options = new ConnectionOptions();
        log.info("Agriscope GetData par le Web Service");
        log.info("Fichier des options : " + options.getFileName());
        log.info("Serveur url         : " + options.getServerUrl());
        log.info("login               : " + options.getLogin());
        log.info("password            : ******");

        log.info("Connection au web service");

        /*
         * ********************************************************************
         * 
         * Mise en place de Spring et recuperation du service AgriscopeWS
         * 
         * *********************************************************************
         */
        ac = new ClassPathXmlApplicationContext(new String[]
                {
                    "com/agriscope/rcp/client/exemple/spring-remote-users-services.xml"
                });


        HttpInvokerProxyFactoryBean invoker = (HttpInvokerProxyFactoryBean) ac.getBean("&rcpUserService");

        // On change le serveur URL par default par le serveur URL spécifies dans les options.
        try
        {
            invoker.setServiceUrl(options.getServerUrl() + "/AgspUserService");
            invoker.afterPropertiesSet();
            ac.refresh();
            agsp = ((AgriscopeWS) invoker.getObject());

        } catch (Exception e)
        {
            log.error(e);
        }

        if (agsp != null)
        {
            log.info("Connecté a " + options.getServerUrl() + "/rcpUserService");
        }

        /*
         * ********************************************************************
         * 
         * Login au service
         * 
         * *********************************************************************
         */

        log.info("Accès au web service par utilisateur " + options.getLogin() );
        try
        {
            loginContext = agsp.login(options.getLogin(), options.getPasswd());
        } catch (AgspException ex)
        {
            log.error(ex);
        }
        log.info("Connection OK !");
        log.info("");


        return loginContext;

    }

    public void printData()
    {
        /*
         * ********************************************************************
         * 
         * Récuperation des agribases (satellite dans le  soft)....
         * qui dependent de l'utilisateurs.
         * 
         * *********************************************************************
         */

        List list = new ArrayList();
        try
        {
            list = agsp.getSatellites(loginContext);
        } catch (AgspException ex)
        {
            log.error(ex);
        }

        Map agribasesData = new HashMap();

        // Pour toutes les agribases
        for (Iterator it = list.iterator(); it.hasNext();)
        {
            AgspSatellite sat = (AgspSatellite) it.next();
            log.info("Agribase " + sat.getName());
            Map sensorsData = new HashMap();
            // Pour tous les capteurs de cette agribases
            for (Iterator it2 = sat.getAgspSensors().iterator(); it2.hasNext();)
            {
                AgspSensor sens = (AgspSensor) it2.next();
                log.info("Capteurs :" + sens.getMeasureTypeName() + ", unite :" + sens.getUnit());

                TimeSeries ts = new TimeSeries("NULL");
                /*
                 * ********************************************************************
                 * 
                 * Requete qui va chercher les données pour le mois de ce capteur
                 * 
                 * *********************************************************************
                 */
                try
                {
                    GregorianCalendar cal  = new GregorianCalendar();
                    cal.setTime(new Date());
                    ts = agsp.dailyQuery(loginContext, sat.getId(), sens.getId(),cal.get(GregorianCalendar.YEAR) ,cal.get(GregorianCalendar.DAY_OF_YEAR));
                } catch (AgspException ex)
                {
                    log.error(ex);
                }
                log.info(this.getTimeSerieDescription(ts));


            }
            log.info("\n\n");
        }


    }
    //
    private String getTimeSerieDescription(TimeSeries ts)
    {
        StringBuffer buf = new StringBuffer();

        buf.append(ts.getTimePeriods().size() + " elements.\n");

        for (Iterator it = ts.getTimePeriods().iterator(); it.hasNext();)
        {
            RegularTimePeriod tp = (RegularTimePeriod) (TimePeriod) it.next();


            // date formatting:
            Date dat = tp.getStart();
            DateFormat dateFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.LONG);

            Number value = (Number) ts.getValue(tp);
            float value2 = Math.round(value.doubleValue() * 100);
            buf.append(dateFormat.format(dat) + "        " + value2 / 100 + "\n");
        }
        return buf.toString();
    }
}
